@@ -51,7 +51,7 @@ class MediaMixin:
         media_id = str(media_pk)
         if "_" not in media_id:
             assert media_id.isdigit(), (
-                "media_id must been contain digits, now %s" % media_id
+                    "media_id must been contain digits, now %s" % media_id
             )
             user = self.media_user(media_id)
             media_id = "%s_%s" % (media_id, user.pk)
@@ -294,12 +294,12 @@ class MediaMixin:
         return result.get("did_delete")
 
     def media_edit(
-        self,
-        media_id: str,
-        caption: str,
-        title: str = "",
-        usertags: List[Usertag] = [],
-        location: Location = None,
+            self,
+            media_id: str,
+            caption: str,
+            title: str = "",
+            usertags: List[Usertag] = [],
+            location: Location = None,
     ) -> Dict:
         """
         Edit caption for media
@@ -460,7 +460,8 @@ class MediaMixin:
         medias = []
         variables = {
             "id": user_id,
-            "first": 50 if not amount or amount > 50 else amount,  # These are Instagram restrictions, you can only specify <= 50
+            "first": 50 if not amount or amount > 50 else amount,
+            # These are Instagram restrictions, you can only specify <= 50
         }
         variables["after"] = end_cursor
         data = self.public_graphql_request(
@@ -483,7 +484,7 @@ class MediaMixin:
         )
 
     def user_medias_gql(
-        self, user_id: int, amount: int = 0, sleep: int = 2
+            self, user_id: int, amount: int = 0, sleep: int = 2
     ) -> List[Media]:
         """
         Get a user's media by Public Graphql API
@@ -507,7 +508,8 @@ class MediaMixin:
         end_cursor = None
         variables = {
             "id": user_id,
-            "first": 50 if not amount or amount > 50 else amount,  # These are Instagram restrictions, you can only specify <= 50
+            "first": 50 if not amount or amount > 50 else amount,
+            # These are Instagram restrictions, you can only specify <= 50
         }
         while True:
             self.logger.info(f"user_medias_gql: {amount}, {end_cursor}")
@@ -778,7 +780,7 @@ class MediaMixin:
         return self.media_archive(media_id, revert=True)
 
     def usertag_medias_gql(
-        self, user_id: int, amount: int = 0, sleep: int = 2
+            self, user_id: int, amount: int = 0, sleep: int = 2
     ) -> List[Media]:
         """
         Get medias where a user is tagged (by Public GraphQL API)
@@ -802,7 +804,8 @@ class MediaMixin:
         end_cursor = None
         variables = {
             "id": user_id,
-            "first": 50 if not amount or amount > 50 else amount,  # These are Instagram restrictions, you can only specify <= 50
+            "first": 50 if not amount or amount > 50 else amount,
+            # These are Instagram restrictions, you can only specify <= 50
         }
         while True:
             if end_cursor:
@@ -885,3 +888,40 @@ class MediaMixin:
         except ClientError:
             medias = self.usertag_medias_v1(user_id, amount)
         return medias
+
+    def media_pin(self, media_pk: str, revert: bool = False):
+        """
+        Pin post to user profile
+
+        Parameters
+        ----------
+        media_pk: str
+        revert: bool, optional
+            Unpin when True
+
+        Returns
+        -------
+        bool
+        A boolean value
+        """
+        data = self.with_action_data({"post_id": media_pk,
+                                      "_uuid": self.uuid})
+        name = "unpin" if revert else "pin"
+
+        result = self.private_request(f"users/{name}_timeline_media/", data)
+        return result["status"] == "ok"
+
+    def media_unpin(self, media_pk):
+        """
+        Pin post to user profile
+
+        Parameters
+        ----------
+        media_pk: str
+
+        Returns
+        -------
+        bool
+        A boolean value
+        """
+        return self.media_pin(media_pk, True)
